@@ -563,10 +563,8 @@ class interp1d(_interp1d):
         )
 
 
-_Interpolator1D = interp1d
 interpolate.interp1d = interp1d
 scipy.interpolate.interp1d = interp1d
-scipy.interpolate.polyint._Interpolator1D = interp1d
 
 from scipy import interpolate
 from scipy import integrate
