@@ -219,7 +219,8 @@ class OMFITuFile(SortedDict, OMFITascii):
             if fig.axes:
                 axes = fig.axes[0]
             else:
-                axes = fig.add_subplot(111)
+                pyplot.figure(num=fig.number)
+                axes = subplot.subplot(111)
         elif axes is not None:
             fig = axes.get_figure()
 
